Crate raps_cli

Crate raps_cli 

RAPS CLI library

This is the main CLI crate that ties together all service crates. The CLI is primarily a binary, but this library module exports components that may be useful for testing or programmatic usage.

Modules

commands
CLI command modules
credits
Demoscene-style credits display for RAPS CLI.
mcp
MCP (Model Context Protocol) Server module
output
plugins
Plugin and Extension System
shell
Interactive shell helper with command completion and hints.