pub fn print_version()Expand description
Print the full demoscene-style credits block.
Colors are automatically stripped when stdout is not a TTY or NO_COLOR is
set, thanks to the colored crate.
pub fn print_version()Print the full demoscene-style credits block.
Colors are automatically stripped when stdout is not a TTY or NO_COLOR is
set, thanks to the colored crate.